@@ -1173,7 +1173,7 @@ game_about_callback (GSimpleAction *action,
   gtk_show_about_dialog (GTK_WINDOW (app),
                          "program-name", _("Five or More"),
                          "version", VERSION,
-                         "comments", _("GNOME port of the once-popular Color Lines game\n\nFive or More is a part of GNOME Games."),
+                         "comments", _("GNOME port of the once-popular Color Lines game"),
                          "copyright",
                          "Copyright © 1997–2008 Free Software Foundation, Inc.\n Copyright © 2013–2014 Michael Catanzaro",
                          "license-type", GTK_LICENSE_GPL_2_0,
